ApiConfig class

Constructors

ApiConfig(String baseUrl, EndpointMode mode)

Properties

actionUrl → String
no setter
appUrl ↔ String
getter/setter pair
baseUrl → String
no setter
endpointMode ↔ EndpointMode
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internationalPaymentUrl → String
no setter
paymentDetailsUrl → String
no setter
returnUrl → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savePenUrl → String
no setter
trackPaymentUrl → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEnvironment(EndpointMode mode) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited