PaymentModel class

Available extensions
Annotations
  • @freezed

Constructors

PaymentModel({required String amount, required String cardNumber, required String expiryDate, required String cvv})
const
factory
PaymentModel.fromJson(Map<String, dynamic> json)
factory

Properties

amount String
no setterinherited
cardNumber String
no setterinherited
copyWith → $PaymentModelCopyWith<PaymentModel>
Create a copy of PaymentModel with the given fields replaced by the non-null parameter values.
no setterinherited
cvv String
no setterinherited
expiryDate String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() bool

Available on PaymentModel, provided by the PaymentModelValidator extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PaymentModel to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited