EncryptCardRequest class
- Annotations
-
- @freezed
Constructors
- EncryptCardRequest({@JsonKey.new(name: 'merchantReference') String? merchantReference, @JsonKey.new(name: 'penzuraYacho') String? penzuraYacho})
-
constfactory
- EncryptCardRequest.fromForm({required String merchantReference, required String pan, required String encrypt(String input)})
-
factory
-
EncryptCardRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $EncryptCardRequestCopyWith<
EncryptCardRequest> -
Create a copy of EncryptCardRequest
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantReference → String?
-
no setterinherited
- penzuraYacho → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this EncryptCardRequest to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited