TrackPaymentRequest class

Annotations
  • @freezed

Constructors

TrackPaymentRequest({@JsonKey.new(name: 'transactionReference') String? transactionReference, @JsonKey.new(name: 'walletName') String? walletName})
const
factory
TrackPaymentRequest.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $TrackPaymentRequestCopyWith<TrackPaymentRequest>
Create a copy of TrackPaymentRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionReference String?
no setterinherited
walletName String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TrackPaymentRequest to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited