GenericResponse class

Annotations
  • @freezed

Constructors

GenericResponse({@JsonKey.new(name: 'status') String? status, @JsonKey.new(name: 'message') String? message, @JsonKey.new(name: 'data') Object? data})
const
factory
GenericResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $GenericResponseCopyWith<GenericResponse>
Create a copy of GenericResponse with the given fields replaced by the non-null parameter values.
no setterinherited
data Object?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GenericResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited