TrackPaymentResponse class

Annotations
  • @freezed

Constructors

TrackPaymentResponse({@JsonKey.new(name: 'status') String? status, @JsonKey.new(name: 'description') String? description, @JsonKey.new(name: 'paymentCurrency') String? paymentCurrency, @JsonKey.new(name: 'paymentAmount') double? paymentAmount, @JsonKey.new(name: 'paymentCharges') double? paymentCharges, @JsonKey.new(name: 'paymentReference') String? paymentReference, @JsonKey.new(name: 'paymentMethod') String? paymentMethod, @JsonKey.new(name: 'paymentDate') String? paymentDate})
const
factory
TrackPaymentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $TrackPaymentResponseCopyWith<TrackPaymentResponse>
Create a copy of TrackPaymentResponse with the given fields replaced by the non-null parameter values.
no setterinherited
description String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
paymentAmount double?
no setterinherited
paymentCharges double?
no setterinherited
paymentCurrency String?
no setterinherited
paymentDate String?
no setterinherited
paymentMethod String?
no setterinherited
paymentReference String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TrackPaymentResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited