TransactionInfoResponse class

Annotations
  • @freezed

Constructors

TransactionInfoResponse({@JsonKey.new(name: 'status') String? status, @JsonKey.new(name: 'applicationID') String? applicationID, @JsonKey.new(name: 'amount') double? amount, @JsonKey.new(name: 'currency') String? currency, @JsonKey.new(name: 'reference') String? reference, @JsonKey.new(name: 'paymentMethod') String? paymentMethod, @JsonKey.new(name: 'expiry') bool? expiry})
const
factory
TransactionInfoResponse.fromJson(Map<String, dynamic> json)
factory

Properties

amount double?
no setterinherited
applicationID String?
no setterinherited
copyWith → $TransactionInfoResponseCopyWith<TransactionInfoResponse>
Create a copy of TransactionInfoResponse with the given fields replaced by the non-null parameter values.
no setterinherited
currency String?
no setterinherited
expiry bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
paymentMethod String?
no setterinherited
reference String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TransactionInfoResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited