ApiResponse<T> class

Generic API response class

Constructors

ApiResponse({T? data, int? statusCode, String? error})
ApiResponse.fromJson(Map<String, dynamic> json, int statusCode)
factory

Properties

data → T?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited