SharedApiService class

API Service class without certificate pinning.

Constructors

SharedApiService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

callApi<T>(String endPoint, ApiMethod method, {Object? body, String? token, Map<String, String>? additionalHeaders, Map<String, String>? queryParams}) Future<ApiResponse<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

alwaysPrintResponse bool
getter/setter pair

Static Methods

customJsonDecode<T>(Response response) → dynamic
setupLogging() → void
Setup logging configuration (call this once from your app init)
updateAlwaysPrintResponse(bool value) → void