PaymentForm class

Inheritance
Mixed-in types
Annotations
  • @FormView.new(fields: [FormTextField(name: 'amount'), FormTextField(name: 'cardNumber'), FormTextField(name: 'expiryDate'), FormTextField(name: 'cvv')])

Constructors

PaymentForm({Key? key, required String paymentCode, required String baseUrl, required EndpointMode endpointMode})
const

Properties

amountController TextEditingController
no setterinherited
amountFocusNode FocusNode
no setterinherited
baseUrl String
final
cardNumberController TextEditingController
no setterinherited
cardNumberFocusNode FocusNode
no setterinherited
createNewViewModelOnInsert bool
When set to true a new ViewModel will be constructed everytime the widget is inserted.
no setterinherited
cvvController TextEditingController
no setterinherited
cvvFocusNode FocusNode
no setterinherited
disposeViewModel bool
Indicates if you want Provider to dispose the ViewModel when it's removed from the widget tree.
no setterinherited
endpointMode EndpointMode
final
expiryDateController TextEditingController
no setterinherited
expiryDateFocusNode FocusNode
no setterinherited
fireOnViewModelReadyOnce bool
Indicates if you want to fire onViewModelReady only once or everytime this widget is inserted into the widget tree.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
initialiseSpecialViewModelsOnce bool
Indicates if you want to only initialise the FutureViewModel or StreamViewModel once or every time it's inserted into the widget tree.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
paymentCode String
final
reactive bool
Indicates if the builder should be rebuilt when notifyListeners is called
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
builder(BuildContext context, PaymentViewModel model, Widget? child) Widget
A function that builds the UI to be shown from the ViewModel - Required
cardWidget(BuildContext context, PaymentViewModel model) Widget
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
disposeForm() → void
Calls dispose on all the generated controllers and focus nodes
inherited
listenToFormUpdated(FormViewModel model) → void
Registers a listener on every generated controller that calls model.setData() with the latest textController values
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(PaymentViewModel viewModel) → void
Fires when the ViewModel is disposed
onModelReady(PaymentViewModel viewModel) → void
Fires when the ViewModel is first created or re-created
inherited
onViewModelReady(PaymentViewModel viewModel) → void
Fires when the ViewModel is first created or re-created
paymentFailed(PaymentViewModel model) Widget
paymentSuccess() Widget
staticChildBuilder(BuildContext context) Widget?
A Function that builds UI for the static child that builds only once
inherited
syncFormWithViewModel(FormStateHelper model) → void
Registers a listener on every generated controller that calls model.setData() with the latest textController values
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
validateFormFields(FormViewModel model) bool
inherited
viewModelBuilder(BuildContext context) PaymentViewModel
A builder that builds the ViewModel for this UI - Required

Operators

operator ==(Object other) bool
The equality operator.
inherited