onDispose method
Fires when the ViewModel is disposed
Useful when working with a form on the view to dispose the form.
Implementation
@override
void onDispose(PaymentViewModel viewModel) {
disposeForm();
super.onDispose(viewModel);
}
Fires when the ViewModel is disposed
Useful when working with a form on the view to dispose the form.
@override
void onDispose(PaymentViewModel viewModel) {
disposeForm();
super.onDispose(viewModel);
}