PaymentService class
Constructors
- PaymentService(String baseUrl, EndpointMode mode)
Properties
- actionUrl → String
-
no setter
- apiConfig ↔ ApiConfig
-
getter/setter pair
- baseUrl → String
-
no setter
- encryptUrl → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- internationalPaymentUrl → String
-
no setter
- returnUrl → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
getter/setter pair
- trackPaymentUrl → String
-
no setter
Methods
-
encryptCard(
EncryptCardRequest encryptCard) → Future< ApiResponse< GenericResponse?> > -
getTransactionInfo(
String? paymentRef) → Future< ApiResponse< TransactionInfoResponse?> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trackPaymentsStatus(
TrackPaymentRequest trackPaymentRequest) → Future< ApiResponse< TrackPaymentResponse?> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited