PaymentForm class
- Inheritance
-
- Mixed-in types
-
- Annotations
-
- @FormView.new(fields: [FormTextField(name: 'amount'), FormTextField(name: 'cardNumber'), FormTextField(name: 'expiryDate'), FormTextField(name: 'cvv')])
Methods
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
inherited
-
builder(BuildContext context, PaymentViewModel model, Widget? child)
→ Widget
-
A function that builds the UI to be shown from the ViewModel - Required
-
cardWidget(BuildContext context, PaymentViewModel model)
→ Widget
-
-
createElement()
→ StatelessElement
-
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
disposeForm()
→ void
-
Calls dispose on all the generated controllers and focus nodes
inherited
-
listenToFormUpdated(FormViewModel model)
→ void
-
Registers a listener on every generated controller that calls
model.setData()
with the latest textController values
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(PaymentViewModel viewModel)
→ void
-
Fires when the ViewModel is disposed
-
onModelReady(PaymentViewModel viewModel)
→ void
-
Fires when the ViewModel is first created or re-created
inherited
-
onViewModelReady(PaymentViewModel viewModel)
→ void
-
Fires when the ViewModel is first created or re-created
-
paymentFailed(PaymentViewModel model)
→ Widget
-
-
paymentSuccess()
→ Widget
-
-
staticChildBuilder(BuildContext context)
→ Widget?
-
A Function that builds UI for the static child that builds only once
inherited
-
syncFormWithViewModel(FormStateHelper model)
→ void
-
Registers a listener on every generated controller that calls
model.setData()
with the latest textController values
inherited
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited
-
validateFormFields(FormViewModel model)
→ bool
-
inherited
-
viewModelBuilder(BuildContext context)
→ PaymentViewModel
-
A builder that builds the ViewModel for this UI - Required